@@ -1,3 +1,3 @@
-QUEUE_NAME = "queue"
+QUEUE_NAME = 'queue'
 QUEUE_CONCURRENCY = 10
 QUEUE_MAX_ATTEMP = 3
